@@ -530,6 +530,22 @@ func TestClusterDeploymentValidate(t *testing.T) {
 			operation:       admissionv1beta1.Update,
 			expectedAllowed: true,
 		},
+		{
+			name: "Test allow modifying installAttemptsLimit",
+			oldObject: func() *hivev1.ClusterDeployment {
+				cd := validAWSClusterDeployment()
+				cd.Spec.InstallAttemptsLimit = new(int32) // zero
+				return cd
+			}(),
+			newObject: func() *hivev1.ClusterDeployment {
+				cd := validAWSClusterDeployment()
+				cd.Spec.InstallAttemptsLimit = new(int32) // zero
+				*cd.Spec.InstallAttemptsLimit = 1
+				return cd
+			}(),
+			operation:       admissionv1beta1.Update,
+			expectedAllowed: true,
+		},
 		{
 			name: "Test invalid wildcard ingress domain",
 			newObject: func() *hivev1.ClusterDeployment {
@@ -766,6 +782,26 @@ func TestClusterDeploymentValidate(t *testing.T) {
 			operation:       admissionv1beta1.Create,
 			expectedAllowed: true,
 		},
+		{
+			name: "OpenStack create without secret reference for certificates",
+			newObject: func() *hivev1.ClusterDeployment {
+				cd := validOpenStackClusterDeployment()
+				cd.Spec.Platform.OpenStack.CertificatesSecretRef = &corev1.LocalObjectReference{Name: ""}
+				return cd
+			}(),
+			operation:       admissionv1beta1.Create,
+			expectedAllowed: false,
+		},
+		{
+			name: "OpenStack create with valid secret reference for certificates",
+			newObject: func() *hivev1.ClusterDeployment {
+				cd := validOpenStackClusterDeployment()
+				cd.Spec.Platform.OpenStack.CertificatesSecretRef = &corev1.LocalObjectReference{Name: "openstack-certificates"}
+				return cd
+			}(),
+			operation:       admissionv1beta1.Create,
+			expectedAllowed: true,
+		},
 		{
 			name:            "Test valid delete",
 			oldObject:       validAWSClusterDeployment(),
