@@ -6,6 +6,14 @@ import (
 )
 
 const (
+	PlatformAWS       = "aws"
+	PlatformAzure     = "azure"
+	PlatformBaremetal = "baremetal"
+	PlatformGCP       = "gcp"
+	PlatformOpenStack = "openstack"
+	PlatformUnknown   = "unknown"
+	PlatformVSphere   = "vsphere"
+
 	mergedPullSecretSuffix = "merged-pull-secret"
 
 	// VeleroBackupEnvVar is the name of the environment variable used to tell the controller manager to enable velero backup integration.
@@ -21,13 +29,6 @@ const (
 	// MinBackupPeriodSecondsEnvVar is the name of the environment variable used to tell the controller manager the minimum period of time between backups.
 	MinBackupPeriodSecondsEnvVar = "HIVE_MIN_BACKUP_PERIOD_SECONDS"
 
-	// SkipGatherLogsEnvVar is the environment variable which passes the configuration to disable
-	// log gathering on failed cluster installs. The value will be either "true" or "false".
-	// If unset "false" should be assumed. This variable is set by the operator depending on the
-	// value of the setting in HiveConfig, passed to the controllers deployment, as well as to
-	// install pods which do the actual log gathering.
-	SkipGatherLogsEnvVar = "SKIP_GATHER_LOGS"
-
 	// InstallJobLabel is the label used for artifacts specific to Hive cluster installations.
 	InstallJobLabel = "hive.openshift.io/install"
 
@@ -189,6 +190,10 @@ const (
 	// path where we mount in the SSH key for connecting to the bare metal libvirt provisioning host.
 	LibvirtSSHPrivKeyPathEnvVar = "LIBVIRT_SSH_PRIV_KEY_PATH"
 
+	// FakeClusterInstallEnvVar is the environment variable Hive will set for the installmanager pod to request
+	// a fake install.
+	FakeClusterInstallEnvVar = "FAKE_INSTALL"
+
 	// ControlPlaneCertificateSuffix is the suffix used when naming objects having to do control plane certificates.
 	ControlPlaneCertificateSuffix = "cp-certs"
 
@@ -275,6 +280,41 @@ const (
 
 	// AWSCredsMount is the location where the AWS credentials secret is mounted for uninstall pods.
 	AWSCredsMount = "/etc/aws-creds"
+
+	// InstallLogsUploadProviderEnvVar is used to specify which object store provider is being used.
+	InstallLogsUploadProviderEnvVar = "HIVE_INSTALL_LOGS_UPLOAD_PROVIDER"
+
+	// InstallLogsUploadProviderAWS is used to specify that AWS is the cloud provider to upload logs to.
+	InstallLogsUploadProviderAWS = "aws"
+
+	// InstallLogsCredentialsSecretRefEnvVar is the environment variable specifying what secret to use for storing logs.
+	InstallLogsCredentialsSecretRefEnvVar = "HIVE_INSTALL_LOGS_CREDENTIALS_SECRET"
+
+	// InstallLogsAWSRegionEnvVar is the environment variable specifying the region to use with S3
+	InstallLogsAWSRegionEnvVar = "HIVE_INSTALL_LOGS_AWS_REGION"
+
+	// InstallLogsAWSServiceEndpointEnvVar is the environment variable specifying the S3 endpoint to use.
+	InstallLogsAWSServiceEndpointEnvVar = "HIVE_INSTALL_LOGS_AWS_S3_URL"
+
+	// InstallLogsAWSS3BucketEnvVar is the environment variable specifying the S3 bucket to use.
+	InstallLogsAWSS3BucketEnvVar = "HIVE_INSTALL_LOGS_AWS_S3_BUCKET"
+
+	// HiveFakeClusterAnnotation can be set to true on a cluster deployment to create a fake cluster that never
+	// provisions resources, and all communication with the cluster will be faked.
+	HiveFakeClusterAnnotation = "hive.openshift.io/fake-cluster"
+
+	// ReconcileIDLen is the length of the random strings we generate for contextual loggers in controller
+	// Reconcile functions.
+	ReconcileIDLen = 8
+
+	// SyncSetMetricsGroupAnnotation can be applied to non-selector SyncSets to make them part of a
+	// group for which first applied metrics can be reported
+	SyncSetMetricsGroupAnnotation = "hive.openshift.io/syncset-metrics-group"
+
+	// ClusterClaimRemoveClusterAnnotation is used by the cluster claim controller to mark that the cluster
+	// that are previously claimed is no longer required and therefore should be removed/deprovisioned and removed
+	// from the pool.
+	ClusterClaimRemoveClusterAnnotation = "hive.openshift.io/remove-claimed-cluster-from-pool"
 )
 
 // GetMergedPullSecretName returns name for merged pull secret name per cluster deployment
