@@ -76,7 +76,11 @@ func Add(mgr manager.Manager) error {
 // NewReconciler returns a new reconcile.Reconciler
 func NewReconciler(mgr manager.Manager, rateLimiter flowcontrol.RateLimiter) reconcile.Reconciler {
 	logger := log.WithField("controller", ControllerName)
-	helper := resource.NewHelperWithMetricsFromRESTConfig(mgr.GetConfig(), ControllerName, logger)
+	helper, err := resource.NewHelperWithMetricsFromRESTConfig(mgr.GetConfig(), ControllerName, logger)
+	if err != nil {
+		// Hard exit if we can't create this controller
+		logger.WithError(err).Fatal("unable to create resource helper")
+	}
 	return &ReconcileRemoteClusterIngress{
 		Client:  controllerutils.NewClientWithMetricsOrDie(mgr, ControllerName, &rateLimiter),
 		scheme:  mgr.GetScheme(),
@@ -127,17 +131,10 @@ type ReconcileRemoteClusterIngress struct {
 // any needed ClusterIngress objects up for syncing to the remote cluster.
 //
 func (r *ReconcileRemoteClusterIngress) Reconcile(request reconcile.Request) (reconcile.Result, error) {
-	start := time.Now()
-	cdLog := r.logger.WithFields(log.Fields{
-		"clusterDeployment": request.Name,
-		"namespace":         request.Namespace,
-	})
+	cdLog := controllerutils.BuildControllerLogger(ControllerName, "clusterDeployment", request.NamespacedName)
 	cdLog.Info("reconciling cluster deployment")
-	defer func() {
-		dur := time.Since(start)
-		hivemetrics.MetricControllerReconcileTime.WithLabelValues(ControllerName.String()).Observe(dur.Seconds())
-		cdLog.WithField("elapsed", dur).Info("reconcile complete")
-	}()
+	recobsrv := hivemetrics.NewReconcileObserver(ControllerName, cdLog)
+	defer recobsrv.ObserveControllerReconcileTime()
 
 	rContext := &reconcileContext{}
 
@@ -282,8 +279,9 @@ func (r *ReconcileRemoteClusterIngress) syncSyncSet(rContext *reconcileContext,
 	newSyncSetSpec := newSyncSetSpec(rContext.clusterDeployment, rawExtensions, secretMappings)
 	syncSet := &hivev1.SyncSet{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      ssName,
-			Namespace: rContext.clusterDeployment.Namespace,
+			Name:        ssName,
+			Namespace:   rContext.clusterDeployment.Namespace,
+			Annotations: map[string]string{constants.SyncSetMetricsGroupAnnotation: "ingress"},
 		},
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "SyncSet",
